import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';

class Rewards extends StatefulWidget {
  const Rewards({super.key});

  @override
  State<Rewards> createState() => _RewardsState();
}

class _RewardsState extends State<Rewards> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();

  @override
  Widget build(BuildContext context) {
    var userRewards = leaderBoardController.userRewards['userRewards']
        as Map<String, dynamic>;
    var rewardGroupNames = userRewards.keys.toList();

    return Column(
        children: rewardGroupNames
            .map((e) => getRewardsGroup(e, userRewards[e]))
            .toList());
  }

  Widget getRewardsGroup(String title, List rewards) {
    return Column(
      children: [
        Center(
          child: Padding(
            padding: const EdgeInsets.only(top: 16.0, bottom: 16.0),
            child: Text(title,
                style: const TextStyle(
                    color: Color(0xFF818181),
                    fontWeight: FontWeight.w500,
                    fontSize: 24,
                    fontFamily: 'Roboto')),
          ),
        ),
        Wrap(
            runAlignment: WrapAlignment.center,
            spacing: 20.0,
            children: rewards
                .map((e) => getRewardItem(
                    e['value'], e['sourceImgUrl'], e['attained'] as bool))
                .toList())
      ],
    );
  }

  Widget getRewardItem(String title, String sourceImgUrl, bool isAttained) {
    return Column(
      children: [
        Container(
          width: 60,
          height: 60,
          decoration: BoxDecoration(
            border: Border.all(color: const Color(0xFF2d6ac2), width: 3),
            shape: BoxShape.circle,
            image: DecorationImage(
              fit: BoxFit.fitWidth,
              image: NetworkImage(sourceImgUrl),
            ),
          ),
        ),
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: Text(isAttained ? '1' : '0',
              style: const TextStyle(
                  color: Color(0xFF818181),
                  fontWeight: FontWeight.w500,
                  fontSize: 16,
                  fontFamily: 'Roboto')),
        ),
      ],
    );
  }
}
