import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:progamification/src/models/leader_board.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:get/get.dart';

class UserDetails extends StatefulWidget {
  const UserDetails({super.key});

  @override
  State<UserDetails> createState() => _UserDetailsState();
}

class _UserDetailsState extends State<UserDetails> {
  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  final GamificationStorageService storageService =
      Get.find<GamificationStorageService>();

  LeaderBoardModel? currentUser = LeaderBoardModel();

  @override
  void initState() {
    setCurrentUserLeaderBoardData();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
          top: MediaQuery.of(context).size.height * 0.02,
          bottom: MediaQuery.of(context).size.height * 0.02),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Column(crossAxisAlignment: CrossAxisAlignment.center, children: [
            const Text('Points',
                style: TextStyle(
                    color: Color(0xFF818181),
                    fontWeight: FontWeight.w500,
                    fontSize: 24,
                    fontFamily: 'Roboto')),
            Text(currentUser != null ? currentUser!.score.toString() : '0',
                style: const TextStyle(
                    color: Color(0xFF562bcb),
                    fontWeight: FontWeight.w600,
                    fontSize: 30,
                    fontFamily: 'Roboto')),
          ]),
          const CircleAvatar(
            radius: 30,
            backgroundImage: AssetImage('assets/icons/profile_placeholder.png',
                package: 'progamification'),
          ),
          Column(crossAxisAlignment: CrossAxisAlignment.center, children: [
            const Text('Rank',
                style: TextStyle(
                    color: Color(0xFF818181),
                    fontWeight: FontWeight.w500,
                    fontSize: 24,
                    fontFamily: 'Roboto')),
            Text(currentUser != null ? currentUser!.rank.toString() : '0',
                style: const TextStyle(
                    color: Color(0xFF562bcb),
                    fontWeight: FontWeight.w600,
                    fontSize: 30,
                    fontFamily: 'Roboto')),
          ]),
        ],
      ),
    );
  }

  Future<void> setCurrentUserLeaderBoardData() async {
    String userId = await storageService.getString('userId');
    LeaderBoardModel leaderboard =
        leaderBoardController.getLeaderBoardData(userId);
    setState(() {
      currentUser = leaderboard;
    });
  }
}
